import unittest
import os.path
import datetime

from pyasn1.type import univ

import rfc3161

class Rfc3161(unittest.TestCase):
    PUBLIC_TSA_SERVER = 'http://time.certum.pl'
    CERTIFICATE = os.path.join(os.path.dirname(__file__),
            '../data/certum_certificate.crt')

    def test_timestamp(self):
        certificate = file(self.CERTIFICATE).read()
        value, substrate = rfc3161.RemoteTimestamper(
                self.PUBLIC_TSA_SERVER, certificate=certificate)(data='xx')
        self.assertIsInstance(rfc3161.get_timestamp(value), datetime.datetime)
        self.assertNotEqual(value, None)
        self.assertEqual(substrate, '')



#!/usr/bin/python
from distutils.core import setup, Command
from unittest import TextTestRunner, TestLoader
from glob import glob
from os.path import splitext, basename, join as pjoin
import os

class TestCommand(Command):
    user_options = [ ]

    def initialize_options(self):
        self._dir = os.getcwd()

    def finalize_options(self):
        pass

    def run(self):
        '''
        Finds all the tests modules in tests/, and runs them.
        '''
        tests = TestLoader().loadTestsFromName('tests.api')
        t = TextTestRunner(verbosity = 1)
        t.run(tests)

setup(name='rfc3161',
        version='0.1.7',
        license='MIT',
        description='Python implementation of the RFC3161 specification, using pyasn1',
        author='Benjamin Dauvergne',
        author_email='bdauvergne@entrouvert.com',
        packages=['rfc3161'],
        requires=['pyasn1'],
        cmdclass={'test': TestCommand})
